%global pname MDAnalysis
%global build_docs 0

%if 0%{?rhel} && 0%{?rhel} <= 6
%{!?__python2: %global __python2 /usr/bin/python2}
%{!?python2_sitelib: %global python2_sitelib %(%{__python2} -c "from distutils.sysconfig import get_python_lib; print(get_python_lib())")}
%{!?python2_sitearch: %global python2_sitearch %(%{__python2} -c "from distutils.sysconfig import get_python_lib; print(get_python_lib(1))")}
%endif

Name: python-%{pname}
Version: 0.14.0
Release: 2%{?dist}
Summary: Analyze and manipulate molecular dynamics trajectories
License: GPLv2+ and BSD and MIT and NCSA and CC-BY-ND
# BSD:
# MDAnalysis/lib/qcprot.pyx
# MDAnalyslis/lib/transformations
# MIT:
# src/KDTree
# NCSA:
# src/dcd
# CC-BY-ND:
# doc/sphinx/source/logos
# GPLv2+:
# everything else
URL: http://www.mdanalysis.org
Source0: https://pypi.python.org/packages/source/M/%{pname}/%{pname}-%{version}.tar.gz
Source1: https://pypi.python.org/packages/source/M/%{pname}Tests/%{pname}Tests-%{version}.tar.gz
Source2: https://github.com/%{pname}/mdanalysis/releases/download/release-%{version}/Documentation.zip
# https://bugzilla.redhat.com/show_bug.cgi?id=1305801
Patch0: python-MDAnalysis-napoleon.patch
# https://github.com/MDAnalysis/mdanalysis/issues/765
Patch1: python-MDAnalysis-issue-765.patch

# we don't want to provide private python extension libs in python2 dirs
%global __provides_exclude_from ^%{python2_sitearch}/.*\\.so$

%global desc \
MDAnalysis is a python framework to analyze molecular dynamics trajectories\
generated by CHARMM, NAMD, LAMMPS, or Gromacs. It is mainly useful for geometric\
analyses, as there is no implemented potential model. \
\
It is inspired by the Schulten Group's MDtools for python, and the source for\
the DCD reading code is derived from VMD. MDAnalysis isGPL licensed, except for\
the dcd reading code (UIUC Open Source Licence) which comes from VMD (and is\
GPL-compatible). Gromacs trajectories are utilizing the Gromacs libxdrfile\
library (GPL). MDAnalysis exposes trajectory data transparently as NumPy arrays\
and as such it is easily extensible.

%description
%{desc}

%package -n python2-%{pname}
Summary: %{summary}
Requires: netcdf4-python
Requires: numpy
Requires: python-biopython
Requires: python-GridDataFormats
Requires: python-matplotlib
Requires: python-networkx
Requires: python-seaborn
Requires: scipy
BuildRequires: Cython
BuildRequires: numpy
BuildRequires: python2-devel
BuildRequires: python-setuptools
%if 0%{?build_docs}
BuildRequires: python-sphinx
%if 0%{?fedora} < 24
BuildRequires: python-sphinxcontrib-napoleon
%endif
%else
BuildRequires: unzip
%endif
# for tests
BuildRequires: netcdf4-python
BuildRequires: python-biopython
BuildRequires: python-GridDataFormats
BuildRequires: python-matplotlib
BuildRequires: python-networkx
BuildRequires: python-nose
BuildRequires: python-tempdir
# MDAnalysis/coordinates/xdrfile/src
Provides: bundled(xdrfile) = 0.7.7
%{?python_provide:%python_provide python2-%{pname}}

%description -n python2-%{pname}
%{desc}

%package doc
Summary: Documentation for MDAnalysis
BuildArch: noarch
License: CC-BY-ND and GPLv2+

%description doc
MDAnalysis is a python framework to analyze molecular dynamics trajectories
generated by CHARMM, NAMD, LAMMPS, or Gromacs. It is mainly useful for geometric
analyses, as there is no implemented potential model.

This package contains the documentation

%prep
%setup -q -n %{pname}-%{version} -a 1
%if 0%{?fedora} < 24
%patch0 -p1 -b .na
%else
pushd MDAnalysisTests-%{version}
%patch1 -p1 -b .issue765
popd
%endif
# force rebuild of Egg Metadata
rm -r %{pname}.egg-info
rm -r %{pname}Tests-%{version}/%{pname}Tests.egg-info

%build
%{py2_build}

pushd %{pname}Tests-%{version}
%{py2_build}
popd

%if 0%{?build_docs}
rm -f MDAnalysis.egg-link easy-install.pth
# https://github.com/MDAnalysis/mdanalysis/wiki/WritingDocumentation#build-the-docs-with-sphinx
PYTHONPATH=%{buildroot}%{python2_sitelib}:%{buildroot}%{python2_sitearch}:$PWD \
%{__python2} setup.py develop -d $PWD
%{__python2} setup.py build_sphinx
%else
mkdir -p build/sphinx/html
unzip %{SOURCE2} -d build/sphinx/html
find build/sphinx/html -type d |xargs chmod 755
%endif

%install
%{py2_install}
find %{buildroot}%{python2_sitearch}/%{pname} -type f -name "*.so" | xargs chmod 755

pushd %{pname}Tests-%{version}
%{py2_install}
popd

%check
%if 1
PYTHONPATH=%{buildroot}%{python2_sitelib}:%{buildroot}%{python2_sitearch}:$(pwd) \
 %{__python2} %{pname}Tests-%{version}/%{pname}Tests/mda_nosetests -v \
 --processes=$(getconf _NPROCESSORS_ONLN) \
 --process-timeout=240
%endif

%files -n python2-%{pname}
%license LICENSE
%doc AUTHORS CHANGELOG README SUMMARY.txt
%{python2_sitearch}/%{pname}-%{version}-py2.?.egg-info
%{python2_sitearch}/%{pname}
%exclude %{python2_sitelib}/%{pname}Tests-%{version}-py2.?.egg-info
%exclude %{python2_sitelib}/%{pname}Tests

%files doc
%license LICENSE
%doc build/sphinx/html/*

%changelog
* Tue Mar 15 2016 Dominik Mierzejewski <rpm@greysector.net> 0.14.0-2
- fix non-standard-dir-perm in doc subpackage
- move python2 build to python2-MDAnalysis subpackage
- exclude private libmdaxdr.so from Provides:

* Fri Mar 11 2016 Dominik Mierzejewski <rpm@greysector.net> 0.14.0-1
- update to 0.14.0
- don't build docs for now, upstream published them in a zip file
- drop obsolete patch
- fix tests with numpy 1.11
- fix license field for docs subpackage
- install LICENSE with the doc subpackage as well
- move building of docs to the build section
- use some python-related convenience macros

* Tue Feb 09 2016 Dominik Mierzejewski <rpm@greysector.net> 0.13.0-2
- build docs
- new dependency: seaborn
- omit failing tests on f24 for now

* Mon Feb 08 2016 Dominik Mierzejewski <rpm@greysector.net> 0.13.0-1
- update to 0.13.0
- fix running tests
- add Provides for bundled xdrfile
- docs not included and failing to build, so disable for now

* Wed Oct 14 2015 Dominik Mierzejewski <rpm@greysector.net> 0.12.1-1
- update to 0.12.1
- drop obsolete patch
- use the new mda_nosetests script for running tests

* Mon May 18 2015 Dominik Mierzejewski <rpm@greysector.net> 0.9.2-4
- relax Improper Torsion topology test check on i686

* Mon May 11 2015 Dominik Mierzejewski <rpm@greysector.net> 0.9.2-3
- document licensing breakdown
- package docs

* Fri May 08 2015 Dominik Mierzejewski <rpm@greysector.net> 0.9.2-2
- call the testsuite per upstream docs

* Wed May 06 2015 Dominik Mierzejewski <rpm@greysector.net> 0.9.2-1
- update to 0.9.2
- update upstream URL
- drop obsolete patch
- fix testsuite invocation

* Wed Feb 04 2015 Dominik Mierzejewski <rpm@greysector.net> 0.8.1-1
- initial build
